Activity Diagrams
=================

Almaqso.process()
-----------------

:numref:`fig-L4-almaqso.Almaqso.process-activity` shows the activity diagram for the :py:meth:`almaqso.Almaqso.process()` method.

.. figure:: diagrams/L4-almaqso.Almaqso.process-activity.svg
   :name: fig-L4-almaqso.Almaqso.process-activity
   :class: thumbnail
   :target: _static/L4-almaqso.Almaqso.process-activity.svg
   :align: center
   :alt: Almaqso.process() Activity Diagram

   Activity diagram of :py:meth:`almaqso.Almaqso.process()`. (Web version: Click to show full-size diagram.)

Almaqso._process_warpper()
----------------------------

:numref:`fig-L4-almaqso.Almaqso._process_wrapper-activity` shows the activity diagram for the :py:meth:`almaqso.Almaqso._process_wrapper()` method.

.. figure:: diagrams/L4-almaqso.Almaqso._process_wrapper-activity.svg
   :name: fig-L4-almaqso.Almaqso._process_wrapper-activity
   :class: thumbnail
   :target: _static/L4-almaqso.Almaqso._process_wrapper-activity.svg
   :align: center
   :alt: Almaqso._process_wrapper() Activity Diagram

   Activity diagram of :py:meth:`almaqso.Almaqso._process_wrapper()`. (Web version: Click to show full-size diagram.)

Almaqso._process()
-------------------

:numref:`fig-L4-almaqso.Almaqso._process-activity` shows the activity diagram for the :py:meth:`almaqso.Almaqso._process()` method.

.. figure:: diagrams/L4-almaqso.Almaqso._process-activity.svg
   :name: fig-L4-almaqso.Almaqso._process-activity
   :class: thumbnail
   :target: _static/L4-almaqso.Almaqso._process-activity.svg
   :align: center
   :alt: Almaqso._process() Activity Diagram

   Activity diagram of :py:meth:`almaqso.Almaqso._process()`. (Web version: Click to show full-size diagram.)

Almaqso._sort_images()
----------------------

:numref:`fig-L4-almaqso.Almaqso.sort_images-activity` shows the activity diagram for the :py:meth:`almaqso.Almaqso.sort_images()` method.

.. figure:: diagrams/L4-almaqso.Almaqso.sort_images-activity.svg
   :name: fig-L4-almaqso.Almaqso.sort_images-activity
   :class: thumbnail
   :target: _static/L4-almaqso.Almaqso.sort_images-activity.svg
   :align: center
   :alt: Almaqso.sort_images() Activity Diagram

   Activity diagram of :py:meth:`almaqso.Almaqso.sort_images()`. (Web version: Click to show full-size diagram.)